@@ -1,19 +1,9 @@
-/* kmahjongg, the classic mahjongg game for KDE project
- *
- * Copyright (C) 1997 Mathias Mueller   <in5y158@public.uni-hamburg.de>
- * Copyright (C) 2006-2007 Mauricio Piacentini   <mauricio@tabuleiro.com>
- *
- * Kmahjongg is free software; you can redistribute it and/or modify it under the terms of the GNU
- * General Public License as published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
- * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along with this program; if
- * not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA. */
+/*
+    SPDX-FileCopyrightText: 1997 Mathias Mueller <in5y158@public.uni-hamburg.de>
+    SPDX-FileCopyrightText: 2006-2007 Mauricio Piacentini <mauricio@tabuleiro.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // own
 #include "kmahjongg.h"
@@ -34,18 +24,20 @@
 #include <QWindowStateChangeEvent>
 #include <QRandomGenerator>
 
-// KDE
+// KF
 #include <KActionCollection>
 #include <KConfigDialog>
-#include <KGameClock>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KScoreDialog>
 #include <KStandardAction>
+
+// KDEGames
+#include <KGameClock>
+#include <KScoreDialog>
 #include <KStandardGameAction>
 
 // LibKMahjongg
-#include <kmahjonggconfigdialog.h>
+#include <KMahjonggConfigDialog>
 
 // KMahjongg
 #include "editor.h"
@@ -58,8 +50,10 @@
 #include "prefs.h"
 #include "ui_settings.h"
 
-const QString KMahjongg::gameMagic = QStringLiteral("kmahjongg-gamedata");
-const int KMahjongg::gameDataVersion = 1;
+namespace {
+inline QString gameMagic() { return QStringLiteral("kmahjongg-gamedata"); }
+constexpr int gameDataVersion = 1;
+}
 
 /**
  * @author Mauricio Piacentini  <mauricio@tabuleiro.com>
@@ -136,17 +130,17 @@ KMahjongg::~KMahjongg()
 
 void KMahjongg::setupKAction()
 {
-    KStandardGameAction::gameNew(this, SLOT(startNewGame()), actionCollection());
-    KStandardGameAction::load(this, SLOT(loadGame()), actionCollection());
-    KStandardGameAction::save(this, SLOT(saveGame()), actionCollection());
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
-    KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
+    KStandardGameAction::gameNew(this, &KMahjongg::startNewGame, actionCollection());
+    KStandardGameAction::load(this, &KMahjongg::loadGame, actionCollection());
+    KStandardGameAction::save(this, &KMahjongg::saveGame, actionCollection());
+    KStandardGameAction::quit(this, &KMahjongg::close, actionCollection());
+    KStandardGameAction::restart(this, &KMahjongg::restartGame, actionCollection());
 
     QAction * newNumGame = actionCollection()->addAction(QStringLiteral("game_new_numeric"));
     newNumGame->setText(i18n("New Numbered Game..."));
     connect(newNumGame, &QAction::triggered, this, &KMahjongg::startNewNumeric);
 
-    QAction * action = KStandardGameAction::hint(m_gameView, SLOT(helpMove()), this);
+    QAction * action = KStandardGameAction::hint(m_gameView, &GameView::helpMove, this);
     actionCollection()->addAction(action->objectName(), action);
 
     QAction * shuffle = actionCollection()->addAction(QStringLiteral("move_shuffle"));
@@ -170,14 +164,14 @@ void KMahjongg::setupKAction()
         this, &KMahjongg::toggleFullscreen, this, actionCollection()
     );
 
-    m_demoAction = KStandardGameAction::demo(this, SLOT(demoMode()), actionCollection());
+    m_demoAction = KStandardGameAction::demo(this, &KMahjongg::demoMode, actionCollection());
 
-    KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
-    m_pauseAction = KStandardGameAction::pause(this, SLOT(pause()), actionCollection());
+    KStandardGameAction::highscores(this, &KMahjongg::showHighscores, actionCollection());
+    m_pauseAction = KStandardGameAction::pause(this, &KMahjongg::pause, actionCollection());
 
     // move
-    m_undoAction = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
-    m_redoAction = KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
+    m_undoAction = KStandardGameAction::undo(this, &KMahjongg::undo, actionCollection());
+    m_redoAction = KStandardGameAction::redo(this, &KMahjongg::redo, actionCollection());
 
     // edit
     QAction * boardEdit = actionCollection()->addAction(QStringLiteral("game_board_editor"));
@@ -185,7 +179,7 @@ void KMahjongg::setupKAction()
     connect(boardEdit, &QAction::triggered, this, &KMahjongg::slotBoardEditor);
 
     // settings
-    KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
+    KStandardAction::preferences(this, &KMahjongg::showSettings, actionCollection());
     setupGUI(qApp->primaryScreen()->geometry().size() * 0.7);
 }
 
@@ -605,7 +599,7 @@ void KMahjongg::loadGame()
     QString magic;
     in >> magic;
 
-    if (QString::compare(magic, gameMagic, Qt::CaseSensitive) != 0) {
+    if (QString::compare(magic, gameMagic(), Qt::CaseSensitive) != 0) {
         KMessageBox::sorry(this, i18n("File is not a KMahjongg game."));
         infile.close();
 
@@ -679,7 +673,7 @@ void KMahjongg::saveGame()
     QDataStream out(&outfile);
 
     // Write a header with a "magic number" and a version
-    out << QString(gameMagic);
+    out << gameMagic();
     out << static_cast<qint32>(gameDataVersion);
     out.setVersion(QDataStream::Qt_4_0);
 
